# MCOauth
This is a simple package to use MCOauth. Initialize a Minecraft Player
``` 
MinecraftPlayer(token)
```
Most things are async except for initializing MinecraftPlayer which is not a blocking call.